%global pkgname carat

Name:           gap-pkg-%{pkgname}
Version:        2.2.3
Release:        3%{?dist}
Summary:        GAP interface to CARAT

License:        GPLv2+
URL:            https://www.math.uni-bielefeld.de/~gaehler/gap45/packages.php
Source0:        https://www.math.uni-bielefeld.de/~gaehler/gap45/Carat/%{pkgname}-%{version}.tar.gz
BuildArch:      noarch

BuildRequires:  carat
BuildRequires:  gap-devel
BuildRequires:  tth

Requires:       carat
Requires:       gap-core

Suggests:       gap-pkg-cryst

%description
This package provides GAP interface routines to some of the standalone
programs of the package CARAT, developed by J. Opgenorth, W. Plesken,
and T. Schulz at Lehrstuhl B für Mathematik, RWTH Aachen.  CARAT is a
package for computation with crystallographic groups.

CARAT is to a large extent complementary to the GAP 4 package Cryst.  In
particular, it provides routines for the computation of normalizers and
conjugators of finite unimodular groups in GL(n,Z), and routines for the
computation of Bravais groups, which are all missing in Cryst.
Furthermore, it provides a catalog of Bravais groups up to dimension 6.
Cryst automatically loads Carat when it is available, and makes use of
its functions where necessary.  The Carat package thereby extends the
functionality of the package Cryst considerably.

%package doc
Summary:        CARAT documentation
Requires:       %{name} = %{version}-%{release}
Requires:       gap-online-help
BuildArch:      noarch

%description doc
This package contains documentation for gap-pkg-%{pkgname}.

%prep
%autosetup -n %{pkgname}

# Don't use the bundled version of CARAT
rm -f carat*.tgz

%build
# Look for the CARAT binaries where they exist in Fedora
for f in read.g PackageInfo.g; do
  sed -i.orig 's,DirectoriesPackagePrograms( "carat" ),Directory( "%{_libexecdir}/carat" ),' $f
  touch -r ${f}.orig $f
  rm -f ${f}.orig
done

# Link to main GAP documentation
ln -s %{_gap_dir}/etc ../../etc
ln -s %{_gap_dir}/doc ../../doc
pushd doc
./make_doc
popd
rm -f ../../{doc,etc}

%install
mkdir -p %{buildroot}%{_gap_dir}/pkg
cp -a ../%{pkgname} %{buildroot}%{_gap_dir}/pkg
rm -f %{buildroot}%{_gap_dir}/pkg/%{pkgname}/{Changelog,GPL,README}
rm -f %{buildroot}%{_gap_dir}/pkg/%{pkgname}/doc/make_doc
rm -f %{buildroot}%{_gap_dir}/pkg/%{pkgname}/doc/*.{aux,bbl,blg,brf,idx,ilg,ind,log,out,pnr}

%check
export LC_ALL=C.UTF-8
gap -l "%{buildroot}%{_gap_dir};%{_gap_dir}" << EOF
LoadPackage( "carat" );
ReadPackage( "carat", "tst/testall.g" );
EOF

%files
%doc Changelog README
%license GPL
%{_gap_dir}/pkg/%{pkgname}/
%exclude %{_gap_dir}/pkg/%{pkgname}/doc/
%exclude %{_gap_dir}/pkg/%{pkgname}/htm/

%files doc
%docdir %{_gap_dir}/pkg/%{pkgname}/doc/
%docdir %{_gap_dir}/pkg/%{pkgname}/htm/
%{_gap_dir}/pkg/%{pkgname}/doc/
%{_gap_dir}/pkg/%{pkgname}/htm/

%changelog
* Fri Feb  1 2019 Jerry James <loganjerry@gmail.com> - 2.2.3-3
- Rebuild for gap 4.10.0
- Add a -doc subpackage

* Thu Jan 31 2019 Fedora Release Engineering <releng@fedoraproject.org> - 2.2.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Tue Nov 20 2018 Jerry James <loganjerry@gmail.com> - 2.2.3-1
- New upstream version
- Add check script

* Tue Oct 30 2018 Jerry James <loganjerry@gmail.com> - 2.2.2-3
- Look for carat binaries in libexecdir instead of libdir

* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.2.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Fri Mar 30 2018 Jerry James <loganjerry@gmail.com> - 2.2.2-1
- New upstream version

* Sat Mar 17 2018 Jerry James <loganjerry@gmail.com> - 2.2.1-1
- New upstream version

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.1.7-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Sat Feb  3 2018 Jerry James <loganjerry@gmail.com> - 2.1.7-1
- New upstream version

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.1.6-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.1.6-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Mon May 23 2016 Jerry James <loganjerry@gmail.com> - 2.1.6-1
- New upstream version (bz 1338766)

* Tue May 17 2016 Jerry James <loganjerry@gmail.com> - 2.1.5-1
- New upstream version

* Thu Apr  7 2016 Jerry James <loganjerry@gmail.com> - 2.1.4-4
- Rebuild for gap 4.8.3

* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 2.1.4-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Wed Nov 11 2015 Jerry James <loganjerry@gmail.com> - 2.1.4-2
- Drop scriptlets; gap-core now uses rpm file triggers
- Rebuild documentation from source

* Fri Jun 19 2015 Jerry James <loganjerry@gmail.com> - 2.1.4-1
- Initial RPM
